#!/usr/bin/env python

import os
import sys
import subprocess
import argparse

def run_command(bash_args):
    process = subprocess.Popen(bash_args, stdout=subprocess.PIPE)
    while True:
        output = process.stdout.readline()
        if output == '' and process.poll() is not None:
            break
        if output:
            print output.strip()
    rc = process.poll()
    return rc

def download_command(input_zip, type):
    """
    The command downloads the input zip file from the server.
    """
    # website url
    base_url = "http://autoland.cs.uni-freiburg.de/static/datasets/" + type + "/"
    # bash command script
    bash_args = ['wget', '-c', base_url + input_zip]
    run_command(bash_args)

def welcome_message():
    print("#########################################")
    print("       Welcome To AutoLand Dataset       ")
    print("#########################################")
    print(">> Starting download for depth data: ")

def main():
    # simulation settings
    intensities = [20, 40, 65, 80, 100]
    tilt_values = range(0, 55, 5)
    pan_values = range(0, 360, 45)
    height_values = range(10, 30, 5)
    type = "depth"

    # welcome message
    welcome_message()

    # run bash command via subprocess
    for pan in pan_values:
        for tilt in tilt_values:
            for height in height_values:
                zip_name = type + "_pan_{:0>3}_tilt_{:0>3}_height_{:0>3}.zip".format(pan, tilt, height)
                download_command(zip_name, type)

if __name__ == "__main__":
    main()
